summaryrefslogtreecommitdiffstats
path: root/python
diff options
context:
space:
mode:
authorJon Marius Venstad <venstad@gmail.com>2020-08-28 09:32:40 +0200
committerJon Marius Venstad <venstad@gmail.com>2020-08-28 09:32:40 +0200
commit5404109687aaf9f4b2374a61c44a6a53cd3b965e (patch)
tree7940e0400317364a4ac7a78b99e8d3a0609e16c8 /python
parent325ecffb37c24ca9538d105b830aaf1e5991c716 (diff)
Fix doc
Diffstat (limited to 'python')
-rw-r--r--python/vespa/vespa/application.py3
1 files changed, 2 insertions, 1 deletions
diff --git a/python/vespa/vespa/application.py b/python/vespa/vespa/application.py
index a5332a2c2d9..6ccf5e8d854 100644
--- a/python/vespa/vespa/application.py
+++ b/python/vespa/vespa/application.py
@@ -23,10 +23,11 @@ class Vespa(object):
:param url: URL
:param port: Port
:param deployment_message: Message returned by Vespa engine after deployment.
:param cert: Certificate and key pair used for mTLS.
>>> Vespa(url = "https://cord19.vespa.ai")
>>> Vespa(url = "http://localhost", port = 8080)
+ >>> Vespa(url = "https://api.vespa-external.aws.oath.cloud", port = 4443, cert = "/path/to/cert-and-key.pem")
"""
self.url = url
@@ -23,10 +23,11 @@ class Vespa(object):
:param port: Port
:param deployment_message: Message returned by Vespa engine after deployment.
- :param cert: Certificate and key pair used for mTLS.
+ :param cert: Path to certificate and key file
>>> Vespa(url = "https://cord19.vespa.ai")
>>> Vespa(url = "http://localhost", port = 8080)